@@ -1,6 +1,7 @@
-from typing import List
+from typing import List, Optional
 import sqlite3
 import re
+from collections import OrderedDict
 
 
 class Book:
@@ -39,6 +40,23 @@ class Book:
         return f"Book({self.book_number_}, {self.short_name_}, {self.long_name_}, {self.book_color_})"
 
 
+class Books:
+    def __init__(self, books):
+        self.books: OrderedDict = OrderedDict()
+
+        for book in books:
+            self.books[book.book_number()] = book
+
+    def contains(self, book):
+        return book in self.books
+
+    def get(self, book):
+        return self.books[book]
+
+    def __iter__(self):
+        return iter(self.books.values())
+
+
 class Info:
     def __init__(self, **kwargs):
         self.configuration = kwargs
@@ -110,10 +128,12 @@ class Verse:
         self.chapter_: int = int(chapter)
         self.verse_: int = int(verse)
 
-        self.text_: str = text
-        self.strip_tags_ = strip_tags
         if strip_tags:
-            self.text_ = self.__strip_tags()
+            self.text_ = self.__strip_tags(text)
+        else:
+            self.text_ = text
+        self.strip_tags_ = strip_tags
+
 
     def __strip_tags(self, text = None) -> str:
         if not text:
@@ -153,10 +173,11 @@ class Verse:
 
 class Verses:
     def __init__(self, verses, strip_tags):
+        self.verses_list = verses
         self.verses = {}
         self.strip_tags_ = strip_tags
 
-        for verse in verses:
+        for verse in self.verses_list:
             book_number, chapter, verse_num = verse.book_number(), verse.chapter(), verse.verse()
             
             if book_number not in self.verses:
@@ -168,9 +189,19 @@ class Verses:
     def strip_tags(self) -> bool:
         return self.strip_tags_
 
-    def get(self, book_number, chapter, verse):
+    def contains(self, book_number, chapter, verse) -> bool:
+        if book_number in self.verses:
+            if chapter in self.verses[book_number]:
+                if verse in self.verses[book_number][chapter]:
+                    return True
+        return False
+
+    def get(self, book_number, chapter, verse) -> Verse:
         return self.verses[book_number][chapter][verse]
 
+    def __iter__(self):
+        return iter(self.verses_list)
+
 
 class Module:
     def __init__(self, filename):
@@ -186,7 +217,7 @@ class Module:
 
         self.info_ = None
 
-    def __parse_books(self, filename) -> List[Book]:
+    def __parse_books(self, filename) -> Books:
         self.cursor.execute('SELECT * FROM books LIMIT 1')
         query_fields = [description[0] for description in self.cursor.description]
         self.cursor.execute(f"SELECT {', '.join(query_fields)} FROM books")
@@ -195,10 +226,10 @@ class Module:
         for row in self.cursor.fetchall():
             result.append(Book(**{key: row[key] for key in row.keys()}))
 
-        return result
+        return Books(result)
 
 
-    def __parse_books_all(self, filename) -> List[Book]:
+    def __parse_books_all(self, filename) -> Books:
         self.cursor.execute('SELECT * FROM books LIMIT 1')
         query_fields = [description[0] for description in self.cursor.description]
         self.cursor.execute(f"SELECT {', '.join(query_fields)} FROM books_all")
@@ -207,7 +238,7 @@ class Module:
         for row in self.cursor.fetchall():
             result.append(Book(**{key: row[key] for key in row.keys()}))
 
-        return result
+        return Books(result)
 
 
     def __parse_info(self, filename) -> Info:
@@ -219,7 +250,7 @@ class Module:
         )
 
 
-    def __parse_verses(self, filename, strip_tags = False) -> List[Verse]:
+    def __parse_verses(self, filename, strip_tags = False) -> Verses:
         self.cursor.execute("SELECT book_number, chapter, verse, text"
                     " FROM verses")
         
